=======
Authors
=======

Core team
----------------

* `Dominique Makowski <https://github.com/DominiqueMakowski>`_ *(Nanyang Technological University, Singapore)*
* `Tam Pham <https://github.com/Tam-Pham>`_ *(Nanyang Technological University, Singapore)*
* `Jan C. Brammer <https://github.com/JohnDoenut>`_ *(Radboud University, Netherlands)*

Contributors
------------

* `Zen Juen Lau <https://github.com/zen-juen>`_ *(Nanyang Technological University, Singapore)*
* `Duy Le <https://github.com/duylp>`_ *(Hubble, Singapore)*
* `Hung Pham <https://github.com/hungpham2511>`_ *(Eureka Robotics, Singapore)*
* `Gansheng Tan <https://github.com/GanshengT>`_ *(CentraleSupélec, France)*
* `Chuan-Peng Hu <https://github.com/hcp4715>`_ *(Universitatsmedizin Mainz, Germany)*
* `François Lespinasse <https://github.com/sangfrois>`_ *(Université de Montréal, Canada)*
* `Christopher Schölzel <https://github.com/CSchoel>`_ *(THM University of Applied Sciences, Germany)*
* `@ucohen <https://github.com/ucohen>`_
* `Anthony Gatti <https://github.com/gattia>`_ *(McMaster University, Canada)*
* `Julien Lamour <https://github.com/lamourj>`_ *(Smood, Switzerland)*
* `@renatosc <https://github.com/renatosc>`_
* `Nicolas Beaudoin-Gagnon <https://github.com/Fegalf>`_ *(Université Laval, Canada)*
* `@rubinovitz <https://github.com/rubinovitz>`_
* `You? <https://neurokit2.readthedocs.io/en/latest/contributing.html>`_

More details `here <https://github.com/neuropsychology/NeuroKit/graphs/contributors>`_.
